@@ -127,25 +127,29 @@ print_packets_string (GString *str,
 
 static inline void
 print_bytes_string (GString *str,
-		    gulong   bytes)
+		    guint64  bytes)
 {
-  bytes *= 10;
-
-  if (bytes > 1048576)
+  if (bytes > 1 << 30)
     {
-      bytes = bytes / 1045576;
+      bytes = (bytes * 10) / (1 << 30);
 
-      g_string_append_printf (str, " (%ld.%ld Mb)", bytes / 10, bytes % 10);
+      g_string_append_printf (str, " (%lld.%lld Gb)", bytes / 10, bytes % 10);
     }
-  else if (bytes > 1024)
+  else if (bytes > 1 << 20)
     {
-      bytes = bytes / 1024;
+      bytes = (bytes * 10) / (1 << 20);
 
-      g_string_append_printf (str, " (%ld.%ld Kb)", bytes / 10, bytes % 10);
+      g_string_append_printf (str, " (%lld.%lld Mb)", bytes / 10, bytes % 10);
+    }
+  else if (bytes > 1 << 10)
+    {
+      bytes = (bytes * 10) / (1 << 10);
+
+      g_string_append_printf (str, " (%lld.%lld Kb)", bytes / 10, bytes % 10);
     }
   else if (bytes >= 0)
     {
-      g_string_append_printf (str, " (%ld.%ld b)", bytes / 10, bytes % 10);
+      g_string_append_printf (str, " (%lld.%lld b)", bytes / 10, bytes % 10);
     }
 }
 
